# libyamlconf

Libyamlconf supports loading configruation form hierarchical YAML files.

## Contribute

This library makes use of [uv](https://github.com/astral-sh/uv) and [ruff](https://github.com/astral-sh/ruff).

Use the following steps to prepare your development enviroment:

- Prepare a virtual environment and install development dependencies: `uv sync`
- Activate the virtual environment: `source .venv/bin/activate`

Please test your changes locally before raising and PR using `./test.sh`
